@@ -99,7 +99,7 @@ class Seti():
     def validate_payment_method(self, methods: List):
         if methods.__len__() == 0:
             return
-        if not methods in ["NEQUI", "PSE", "CARD"]:
+        if len(set(methods) & set(["NEQUI", "PSE", "CARD"])) == 0:
             raise MyException({'msg': 'Invalid Payment Method', 'code': 4})
 
     # Payments
