@@ -28,7 +28,10 @@ class NewUsers:
     secret: str
 
     def __init__(self, data: dict):
-        self.secret = data['secret']
+        try:
+            self.secret = data['secret']
+        except Exception:
+            self.secret = ""
 
 
 class ResponseCreateUser(BasicResponse):
@@ -37,6 +40,7 @@ class ResponseCreateUser(BasicResponse):
     def __init__(self, data: dict):
         self.msg = data['msg']
         self.res = data['res']
+
         if data['res'] == 200:
             self.data = NewUsers(data['data'])
         else:
